]> de.git.xonotic.org Git - xonotic/darkplaces.git/blobdiff - netconn.c
corrected some svc_nop's to clc_nop's (same value but more correct)
[xonotic/darkplaces.git] / netconn.c
index 8f31e4e8193827e1ecaf35c876b75dbce05f97df..8ddc8aa59d3de099f0f82bd39615150f1e371301 100755 (executable)
--- a/netconn.c
+++ b/netconn.c
@@ -1092,14 +1092,14 @@ void NetConn_ConnectionEstablished(lhnetsocket_t *mysocket, lhnetaddress_t *peer
                Cmd_ForwardStringToServer("new");
        if (cls.protocol == PROTOCOL_QUAKE)
        {
// write a keepalive (svc_nop) as it seems to greatly improve the
                // chances of connecting to a netquake server
                sizebuf_t msg;
                unsigned char buf[4];
                memset(&msg, 0, sizeof(msg));
                msg.data = buf;
                msg.maxsize = sizeof(buf);
-               MSG_WriteChar(&msg, svc_nop);
+               MSG_WriteChar(&msg, clc_nop);
                NetConn_SendUnreliableMessage(cls.netcon, &msg, cls.protocol);
        }
 }
@@ -1092,14 +1092,14 @@ void NetConn_ConnectionEstablished(lhnetsocket_t *mysocket, lhnetaddress_t *peer
        if (cls.protocol == PROTOCOL_QUAKE)
        {
-               // write a keepalive (svc_nop) as it seems to greatly improve the
+               // write a keepalive (clc_nop) as it seems to greatly improve the
                // chances of connecting to a netquake server
                sizebuf_t msg;